==> haskell-hslua-core-2.3.2-28-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-core
version:              2.3.2
visibility:           public
id:                   hslua-core-2.3.2-AavBLrXCtfgGcXsnxoEylh
key:                  hslua-core-2.3.2-AavBLrXCtfgGcXsnxoEylh
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2024 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Bindings to Lua, an embeddable scripting language
description:
    Wrappers and helpers to bridge Haskell and
    <https://www.lua.org/ Lua>.

    It builds upon the /lua/ package, which allows to bundle
    a Lua interpreter with a Haskell program.

category:             Foreign
abi:                  f3100d39cefbeb223dc929db14102109
exposed:              True
exposed-modules:
    HsLua.Core, HsLua.Core.Closures, HsLua.Core.Debug,
    HsLua.Core.Error, HsLua.Core.Package, HsLua.Core.Run,
    HsLua.Core.Trace, HsLua.Core.Types, HsLua.Core.Unsafe,
    HsLua.Core.Userdata, HsLua.Core.Utf8,
    Lua from lua-2.3.3-EbpMjC0lLOkA0uMVN1Mpuc:Lua

hidden-modules:
    HsLua.Core.Auxiliary HsLua.Core.Primary HsLua.Core.Warn

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-core-2.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-core-2.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-core-2.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-core
hs-libraries:         HShslua-core-2.3.2-AavBLrXCtfgGcXsnxoEylh
depends:
    base-4.18.2.1 bytestring-0.11.5.3 exceptions-0.10.7
    lua-2.3.3-EbpMjC0lLOkA0uMVN1Mpuc mtl-2.3.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-hslua-core/html/hslua-core.haddock
haddock-html:         /usr/share/doc/haskell-hslua-core/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-core-2.3.2-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-core
version:              2.3.2
visibility:           public
id:                   hslua-core-2.3.2-1qLa3MGyBQiANefVWn9OZL
key:                  hslua-core-2.3.2-1qLa3MGyBQiANefVWn9OZL
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2024 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Bindings to Lua, an embeddable scripting language
description:
    Wrappers and helpers to bridge Haskell and
    <https://www.lua.org/ Lua>.

    It builds upon the /lua/ package, which allows to bundle
    a Lua interpreter with a Haskell program.

category:             Foreign
abi:                  b04623409df2f78007cbbf16ad44a749
exposed:              True
exposed-modules:
    HsLua.Core, HsLua.Core.Closures, HsLua.Core.Debug,
    HsLua.Core.Error, HsLua.Core.Package, HsLua.Core.Run,
    HsLua.Core.Trace, HsLua.Core.Types, HsLua.Core.Unsafe,
    HsLua.Core.Userdata, HsLua.Core.Utf8,
    Lua from lua-2.3.4-KElaEqaQo7F6TpbIXheLsG:Lua

hidden-modules:
    HsLua.Core.Auxiliary HsLua.Core.Primary HsLua.Core.Warn

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-core-2.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-core-2.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-core-2.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-core
hs-libraries:         HShslua-core-2.3.2-1qLa3MGyBQiANefVWn9OZL
depends:
    base-4.18.2.1 bytestring-0.11.5.3 exceptions-0.10.7
    lua-2.3.4-KElaEqaQo7F6TpbIXheLsG mtl-2.3.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-hslua-core/html/hslua-core.haddock
haddock-html:         /usr/share/doc/haskell-hslua-core/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
